pub struct Chunk {
pub chunk: [usize; 2],
pub data: Bytes,
pub meta: ChunkMeta,
}Expand description
One chunk of a chunked message, as it travels on the wire.
Fields
chunk: [usize; 2][position, total] — this chunk’s index and the number of chunks in the message.
data: Byteschunk payload bytes
meta: ChunkMetameta data of chunk
Implementations