PeerRingRemoteAction

Enum PeerRingRemoteAction 

pub enum PeerRingRemoteAction {
    FindSuccessor(Did),
    FindEntry(EntryLookupKey),
    FindEntryForOperate(EntryOperation),
    Notify(Did),
    SyncEntriesWithSuccessor(Vec<PlacedEntry>),
    FindSuccessorForConnect(Did),
    FindSuccessorForFix {
        did: Did,
        index: usize,
    },
    QueryForSuccessorList,
    QueryForSuccessorListAndPred,
    TryConnect,
}
Some of the process needs to be done remotely. This enum is used to describe that. Don’t worry about leaving the context. There will be callback machinisim externally that will invoke appropriate methods in PeerRing to continue the process.

To avoid ambiguity, in the following comments, did_a is the Did declared in PeerRingAction. Other dids are the fields declared in this RemoteAction.

Variants



FindSuccessor(Did)

Need did_a to find did_b.



FindEntry(EntryLookupKey)

Need did_a to find one entry placement.



FindEntryForOperate(EntryOperation)

Need did_a to find Entry for operating.



Notify(Did)

Send a predecessor notification to did_a.

did_a is the remote recipient from PeerRingAction::RemoteAction. This field is the predecessor DID announced in NotifyPredecessorSend.



SyncEntriesWithSuccessor(Vec<PlacedEntry>)

Copy placed entries to the storage destination represented by did_a.

In successor hand-off, did_a is the new successor node. In repair and republish, did_a is the placement key and the message layer routes it to that key’s current successor.



FindSuccessorForConnect(Did)

Need did_a to find did_b then send back with for connect flag.



FindSuccessorForFix

Need did_a to find did_b then send back with for finger table fixing flag.

Fields

did: Did

DID whose successor should populate the finger slot.

index: usize

Finger slot that should be updated by the report.



QueryForSuccessorList

Fetch successor_list from successor



QueryForSuccessorListAndPred

Fetch successor_list and pred from successor



TryConnect

Try connect to a Node