pub enum StorageSyncPurpose {
OwnershipHandoff,
AdditiveRepair,
}Expand description
Storage-sync transition kind.
Cleanup law: only StorageSyncPurpose::OwnershipHandoff reports can prove
source-side deletion. StorageSyncPurpose::AdditiveRepair is copy-only and
must never create a delete-capable ack.
Variants
OwnershipHandoff
Ownership changed and the sender may delete after a durable matching ack.
AdditiveRepair
Additive read-repair or anti-entropy copy.
Implementations
Sourceimpl StorageSyncPurpose
impl StorageSyncPurpose
Sourcepub const fn permits_source_cleanup(self) -> bool
pub const fn permits_source_cleanup(self) -> bool
Returns whether reports for this sync kind may drive source cleanup.