PeerRing

Struct PeerRing 

pub struct PeerRing {
    pub did: Did,
    pub finger: Arc<Mutex<FingerTable>>,
    pub successor_seq: SuccessorSeq,
    pub predecessor: Arc<Mutex<Option<Did>>>,
    pub storage: EntryStorage,
    pub cache: EntryStorage,
}
PeerRing is used to help a node interact with other nodes. All nodes in rings network form a clockwise ring in the order of Did. This struct takes its name from that. PeerRing implemented Chord algorithm. PeerRing implemented ChordStorage protocol.

Fields

did: Did

The did of current node.

finger: Arc<Mutex<FingerTable>>

FingerTable help node to find successor quickly.

successor_seq: SuccessorSeq

The next node on the ring. The SuccessorSeq may contain multiple node dids for fault tolerance. The min did should be same as the first element in finger table.

predecessor: Arc<Mutex<Option<Did>>>

The did of previous node on the ring.

storage: EntryStorage

Local storage for ChordStorage.

cache: EntryStorage

Local cache for ChordStorage.

Implementations

Source

impl PeerRing

pub fn new_with_storage(did: Did, succ_max: u8, storage: EntryStorage) -> Self

Same as new with config, but with a given storage.

pub fn new_with_storage_and_finger_table_size( did: Did, succ_max: u8, storage: EntryStorage, finger_table_size: usize, ) -> Self

Same as new with config, but with a given storage and finger table size.

Did is 160-bit. Sizes above DEFAULT_FINGER_TABLE_SIZE are clamped by FingerTable::new; zero is allowed to disable finger maintenance.

pub fn lock_successor(&self) -> Result<SuccessorSeq>

👎Deprecated

Return successor sequence. This function is deprecated, please use [chord.successors] instead.

pub fn successors(&self) -> SuccessorSeq

Return successor sequence

pub fn lock_finger(&self) -> Result<MutexGuard<'_, FingerTable>>

Lock and return MutexGuard of finger table.

pub fn lock_predecessor(&self) -> Result<MutexGuard<'_, Option<Did>>>

Lock and return MutexGuard of predecessor.

pub fn remove(&self, did: Did) -> Result<()>

Remove a node from finger table. Also remove it from successor sequence. If successor_seq become empty, try setting the closest node to it.

pub fn bias(&self, did: Did) -> BiasId

Calculate bias of the Did on the ring.