pub enum AccountVerifier {
Recoverable {
algorithm: SignatureAlgorithm,
did: Did,
},
PublicKey(VerificationPublicKey),
}Expand description
Public verifier for an account signature.
Recoverable signature schemes can use DID/address plus algorithm, while non-recoverable schemes must carry the explicit public key.
Variants
Recoverable
Recoverable signature schemes can identify the account by DID/address.
PublicKey(VerificationPublicKey)
Non-recoverable schemes must carry the public key.
Implementations
Sourceimpl AccountVerifier
impl AccountVerifier
Sourcepub fn from_account_parts(
account_entity: &str,
account_type: &str,
) -> Result<Self>
pub fn from_account_parts( account_entity: &str, account_type: &str, ) -> Result<Self>
Parse a legacy session account pair into an account verifier.
Sourcepub fn algorithm(&self) -> SignatureAlgorithm
pub fn algorithm(&self) -> SignatureAlgorithm
Signature algorithm for this account verifier.
Sourcepub fn verification_key_from_signature(
&self,
msg: &[u8],
sig: impl AsRef<[u8]>,
) -> Result<VerificationPublicKey>
pub fn verification_key_from_signature( &self, msg: &[u8], sig: impl AsRef<[u8]>, ) -> Result<VerificationPublicKey>
Recover or return the explicit public verification key for this verifier.