macro_rules! poll {
( $future:expr, $ttl:expr ) => { ... };
}Expand description
Schedule a future expression repeatedly with a wasm timeout.
macro_rules! poll {
( $future:expr, $ttl:expr ) => { ... };
}Schedule a future expression repeatedly with a wasm timeout.