pub struct E2eStreamDecryptor { /* private fields */ }Expand description
Stateful streaming decryptor for direct ElGamal body frames.
Implementations
Sourceimpl E2eStreamDecryptor
impl E2eStreamDecryptor
Sourcepub fn new(
stream_id: E2eStreamId,
expected_sender: Did,
recipient_secret_key: SecretKey,
) -> Self
pub fn new( stream_id: E2eStreamId, expected_sender: Did, recipient_secret_key: SecretKey, ) -> Self
Create a direct ElGamal streaming decryptor for a recipient secret key.
Sourcepub fn with_reorder_window(
stream_id: E2eStreamId,
expected_sender: Did,
recipient_secret_key: SecretKey,
reorder_window: u64,
) -> Self
pub fn with_reorder_window( stream_id: E2eStreamId, expected_sender: Did, recipient_secret_key: SecretKey, reorder_window: u64, ) -> Self
Create a decryptor with an explicit future-frame reorder window.
Sourcepub fn decrypt_next(&mut self, frame: &E2eStreamFrame) -> Result<Vec<u8>>
pub fn decrypt_next(&mut self, frame: &E2eStreamFrame) -> Result<Vec<u8>>
Decrypt one frame and return newly contiguous plaintext bytes.
Out-of-order future frames are buffered and return an empty vector until the missing lower sequence numbers arrive.