pub struct MessagePayload {
pub transaction: Transaction,
pub relay: MessageRelay,
pub verification: MessageVerification,
}Expand description
MessagePayload is used to transmit data between nodes.
The data should be packed by Transaction.
Fields
transaction: TransactionPayload data
relay: MessageRelayRelay records the transport path of message. And can also help message sender to find the next hop.
verification: MessageVerificationThis field holds a signature from a node, which is used to prove that payload was created by that node.
Implementations
Sourceimpl MessagePayload
impl MessagePayload
Sourcepub fn new(
transaction: Transaction,
session_sk: &SessionSk,
relay: MessageRelay,
) -> Result<Self>
pub fn new( transaction: Transaction, session_sk: &SessionSk, relay: MessageRelay, ) -> Result<Self>
Create new MessagePayload.
Need Transaction, SessionSk and MessageRelay.
Sourcepub fn new_send<T>(
data: T,
session_sk: &SessionSk,
next_hop: Did,
destination: Did,
) -> Result<Self>where
T: Serialize,
pub fn new_send<T>(
data: T,
session_sk: &SessionSk,
next_hop: Did,
destination: Did,
) -> Result<Self>where
T: Serialize,
Helps to create sending message from data.
Sourcepub fn from_bincode(data: &[u8]) -> Result<Self>
pub fn from_bincode(data: &[u8]) -> Result<Self>
Deserializes a MessagePayload instance from the given binary data.
Sourcepub fn to_bincode(&self) -> Result<Bytes>
pub fn to_bincode(&self) -> Result<Bytes>
Serializes the MessagePayload instance into binary data.