pub struct Session { /* private fields */ }Expand description
Session is used to verify the message. It’s serializable and can be attached to the message payload.
To verify the session is provided by the account, use session.verify_self(). To verify the message, use session.verify(msg, sig).
Implementations
Sourceimpl Session
impl Session
Sourcepub fn pack(&self) -> Vec<u8> ⓘ
pub fn pack(&self) -> Vec<u8> ⓘ
Pack the session into a string for verification or public key recovery.
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check session is expired or not.
Sourcepub fn verify_self(&self) -> Result<()>
pub fn verify_self(&self) -> Result<()>
Verify session.
Sourcepub fn account_pubkey(&self) -> Result<PublicKey<33>>
pub fn account_pubkey(&self) -> Result<PublicKey<33>>
Get legacy secp256k1-compatible account public key.
Use account_verification_pubkey for typed account verification keys.
Sourcepub fn account_verification_pubkey(&self) -> Result<VerificationPublicKey>
pub fn account_verification_pubkey(&self) -> Result<VerificationPublicKey>
Get typed account verification public key from session proof.
Sourcepub fn account_verifier(&self) -> AccountVerifier
pub fn account_verifier(&self) -> AccountVerifier
Get typed account verifier.
Sourcepub fn account_did(&self) -> Did
pub fn account_did(&self) -> Did
Get account did.