pub struct SessionSkBuilder { /* private fields */ }Expand description
SessionSkBuilder is used to build a SessionSk.
Firstly, you need to provide the account’s entity and type to SessionSkBuilder::new method.
Then you can call pack_session to get the session dump for signing.
After signing, you can call sig to set the signature back to builder.
Finally, you can call build to get the SessionSk.
Implementations
Sourceimpl SessionSkBuilder
impl SessionSkBuilder
Sourcepub fn new(account_entity: String, account_type: String) -> SessionSkBuilder
pub fn new(account_entity: String, account_type: String) -> SessionSkBuilder
Sourcepub fn validate_account(&self) -> bool
pub fn validate_account(&self) -> bool
This is a helper method to let user know if the account params is valid.
Sourcepub fn unsigned_proof(&self) -> String
pub fn unsigned_proof(&self) -> String
Construct unsigned_info string for signing.
Sourcepub fn set_session_sig(self, sig: Vec<u8>) -> Self
pub fn set_session_sig(self, sig: Vec<u8>) -> Self
Set the signature of session that signed by account.