#[non_exhaustive]pub enum SwarmEvent {
ConnectionStateChange {
peer: Did,
state: WebrtcConnectionState,
},
}Expand description
Used to notify the application of events that occur in the swarm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConnectionStateChange
Indicates that the connection state of a peer has changed.
Fields

state: WebrtcConnectionStateThe final state of the connection.