Struct rings_core::swarm::Swarm

source ·
pub struct Swarm { /* private fields */ }
The transport and dht management.

Implementations

source

impl Swarm

source

pub async fn record_sent(&self, did: Did)

Record a succeeded message sent

source

pub async fn record_sent_failed(&self, did: Did)

Record a failed message sent

source

pub async fn behaviour_good(&self, did: Did) -> bool

Check that a Did is behaviour good

source

pub async fn new_connection(&self, did: Did) -> Result<Connection>

Create new connection that will be handled by swarm.

source

pub async fn get_and_check_connection(&self, did: Did) -> Option<Connection>

Get connection by did and check if it is connected.

source

pub fn get_connection(&self, did: Did) -> Option<Connection>

Get connection by did.

source

pub fn get_connections(&self) -> Vec<(Did, Connection)>

Get all connections in transport.

source

pub fn get_connection_ids(&self) -> Vec<Did>

Get dids of all connections in transport.

source

impl Swarm

source

pub fn did(&self) -> Did

Get did of self.

source

pub fn dht(&self) -> Arc<PeerRing>

Get DHT(Distributed Hash Table) of self.

source

pub fn session_sk(&self) -> &SessionSk

Retrieves the session sk associated with the current instance. The session sk provides a segregated approach to manage private keys. It generates session secret keys for the bound entries of PKIs (Public Key Infrastructure).

source

pub async fn poll_message(&self) -> Option<MessagePayload<Message>>

This method is required because web-sys components is not Send which means an async loop cannot running concurrency.

source

pub async fn listen_once( &self ) -> Option<(MessagePayload<Message>, Vec<MessageHandlerEvent>)>

This method is required because web-sys components is not Send This method will return events already consumed (landed), which is ok to be ignore. which means a listening loop cannot running concurrency.

source

pub async fn handle_message_handler_event( &self, event: &MessageHandlerEvent ) -> Result<Vec<MessageHandlerEvent>>

Event handler of Swarm.

source

pub fn handle_message_handler_events<'life0, 'life_self, 'async_recursion>( &'life_self self, events: &'life0 Vec<MessageHandlerEvent> ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_recursion>>where 'life0: 'async_recursion, 'life_self: 'async_recursion,

Batch handle events

source

pub async fn disconnect(&self, did: Did) -> Result<()>

Disconnect a connection. There are three steps:

  1. remove from DHT;
  2. remove from Transport;
  3. close the connection;
source

pub async fn connect(&self, did: Did) -> Result<Connection>

Connect a given Did. If the did is already connected, return directly, else try prepare offer and establish connection by dht. This function may returns a pending connection or connected connection.

source

pub async fn connect_via(&self, did: Did, next_hop: Did) -> Result<Connection>

Similar to connect, but this function will try connect a Did by given hop.

source

pub async fn inspect(&self) -> SwarmInspect

Check the status of swarm

source

impl Swarm

source

pub async fn listen(self: Arc<Self>)

Listener for native envirement, It will just launch a loop.