pub struct PublicKey<const SIZE: usize>(pub [u8; SIZE]);Expand description
PublicKey for ECDSA and EdDSA.
Tuple Fields
0: [u8; SIZE]Implementations
Sourceimpl PublicKey<33>
impl PublicKey<33>
Sourcepub fn try_from_b58t(value: &str) -> Result<PublicKey<33>>
pub fn try_from_b58t(value: &str) -> Result<PublicKey<33>>
trezor style b58
Sourcepub fn try_from_b58m(value: &str) -> Result<PublicKey<33>>
pub fn try_from_b58m(value: &str) -> Result<PublicKey<33>>
monero and bitcoin style b58
Sourcepub fn try_from_b58m_uncheck(value: &str) -> Result<PublicKey<33>>
pub fn try_from_b58m_uncheck(value: &str) -> Result<PublicKey<33>>
monero style uncheck base56
Sourcepub fn from_u8(value: &[u8]) -> Result<PublicKey<33>>
pub fn from_u8(value: &[u8]) -> Result<PublicKey<33>>
from raw u8, the length can be 32, or 33 Odd flag can be “02” (odd), “03” (even) or “00” (unknown) The format is <odd_flat (1 bytes), x_coordinate (32 bytes)> For 32 bytes case, we mark the odd flas as 00 (unknown) For 64 bytes case, we compress the public key into compressed public key
Sourcepub fn to_base58_string(&self) -> Result<String>
pub fn to_base58_string(&self) -> Result<String>
convert pubkey to base58_string
Sourcepub fn from_hex_string(value: &str) -> Result<PublicKey<33>>
pub fn from_hex_string(value: &str) -> Result<PublicKey<33>>
convert public_key from hex string
Sourceimpl<const SIZE: usize> PublicKey<SIZE>
impl<const SIZE: usize> PublicKey<SIZE>
Sourcepub fn from_exact_u8(value: &[u8]) -> Result<PublicKey<SIZE>>
pub fn from_exact_u8(value: &[u8]) -> Result<PublicKey<SIZE>>
Build a public key from exactly SIZE bytes.
Sourceimpl PublicKey<33>
impl PublicKey<33>
Sourcepub fn ct_into_secp256r1_affine(self) -> CtOption<AffinePoint<NistP256>>
pub fn ct_into_secp256r1_affine(self) -> CtOption<AffinePoint<NistP256>>
Map a PublicKey into secp256r1 affine point, This function is an constant-time cryptographic implementations
Sourcepub fn ct_try_into_secp256r1_pubkey(
self,
) -> CtOption<Result<VerifyingKey<NistP256>>>
pub fn ct_try_into_secp256r1_pubkey( self, ) -> CtOption<Result<VerifyingKey<NistP256>>>
Map a PublicKey into secp256r1 public key, This function is an constant-time cryptographic implementations